'use client'
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var walletConnectorCore = require('@dynamic-labs/wallet-connector-core');
var utils = require('@dynamic-labs/utils');
var getConnectorConstructorForEip6963Wallet = require('../utils/getConnectorConstructorForEip6963Wallet/getConnectorConstructorForEip6963Wallet.cjs');
var getConnectorConstructorInjectedWallet = require('../utils/getConnectorConstructorInjectedWallet/getConnectorConstructorInjectedWallet.cjs');
var PhantomEvm = require('./PhantomEvm.cjs');
var ExodusEvm = require('./ExodusEvm.cjs');

const injectedWalletOverrides = [
    PhantomEvm.PhantomEvm,
    ExodusEvm.ExodusEvm,
];
let removeEip6963EventsListener;
// should add eip6963 connector only if not in wallet-book, to avoid adding duplicate connectors
const shouldAddEip6963Connector = (eip6963ProviderInfo, walletBook, walletsWithCustomConnectors) => {
    var _a;
    const { rdns, name } = eip6963ProviderInfo;
    const chain = 'evm';
    const connectorKey = `${utils.sanitizeName(name)}${chain}`;
    walletConnectorCore.logger.logVerboseTroubleshootingMessage('[ETH shouldAddEip6963Connector]', rdns, name, chain, connectorKey);
    const existingWallet = Object.entries((_a = walletBook === null || walletBook === void 0 ? void 0 : walletBook.wallets) !== null && _a !== void 0 ? _a : {}).find(([key, wallet]) => {
        var _a, _b;
        return ((_a = wallet.eip6963Config) === null || _a === void 0 ? void 0 : _a.rdns) === rdns ||
            key === connectorKey ||
            walletsWithCustomConnectors.includes(connectorKey) ||
            (wallet.name === name && ((_b = wallet.injectedConfig) === null || _b === void 0 ? void 0 : _b[0].chain) === chain);
    });
    walletConnectorCore.logger.logVerboseTroubleshootingMessage('[ETH shouldAddEip6963Connector]', existingWallet);
    return !existingWallet;
};
const addEip6963Listener = (walletBook, walletsWithCustomConnectors) => {
    removeEip6963EventsListener === null || removeEip6963EventsListener === void 0 ? void 0 : removeEip6963EventsListener();
    removeEip6963EventsListener = utils.listenToEip6963Events((event) => {
        if (!shouldAddEip6963Connector(event.detail.info, walletBook, walletsWithCustomConnectors)) {
            return;
        }
        walletConnectorCore.logger.logVerboseTroubleshootingMessage('[ETH fetchInjectedWalletConnectors] listenToEip6963Events', event.detail);
        walletConnectorCore.walletConnectorEvents.emit('providerInjected', {
            injectedConnectorConstructor: getConnectorConstructorForEip6963Wallet.getConnectorConstructorForEip6963Wallet(event.detail),
        });
    });
};
const fetchInjectedWalletConnector = ({ walletBook, walletsWithCustomConnectors, }) => {
    var _a;
    addEip6963Listener(walletBook, walletsWithCustomConnectors);
    const walletBookConnectors = Object.entries((_a = walletBook === null || walletBook === void 0 ? void 0 : walletBook.wallets) !== null && _a !== void 0 ? _a : {})
        .filter(([key, wallet]) => {
        var _a;
        return ((_a = wallet.injectedConfig) === null || _a === void 0 ? void 0 : _a.find((config) => config.chain === 'evm')) &&
            !walletsWithCustomConnectors.includes(key);
    })
        .map(([key, wallet]) => getConnectorConstructorInjectedWallet.getConnectorConstructorInjectedWallet(key, wallet));
    const { providers } = utils.Eip6963ProviderSingleton.get();
    const eip6963Connectors = providers
        .filter((provider) => shouldAddEip6963Connector(provider.info, walletBook, walletsWithCustomConnectors))
        .map((provider) => getConnectorConstructorForEip6963Wallet.getConnectorConstructorForEip6963Wallet(provider));
    walletConnectorCore.logger.logVerboseTroubleshootingMessage('[ETH fetchInjectedWalletConnectors] eip6963Connectors', eip6963Connectors);
    return [...walletBookConnectors, ...eip6963Connectors];
};

exports.fetchInjectedWalletConnector = fetchInjectedWalletConnector;
exports.injectedWalletOverrides = injectedWalletOverrides;
